function loadlevel(filename) --loads level data from text file
	local file=love.filesystem.newFile(filename)
	
	--various variables
	objectnum=1
	object_x={}
	object_y={}
	object_type={}
	shape_x={}
	shape_y={}
	shape_width={}
	shape_height={}
	shape_amount={}
	
	file:open("r")
	for line in file:lines() do
		local currentline=line
		object_x[objectnum]=tonumber(string.sub(currentline,1,string.find(currentline,",")-1)) --load coordinates of object
		currentline=string.sub(currentline,string.find(currentline,",")+1)
		object_y[objectnum]=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
		currentline=string.sub(currentline,string.find(currentline,",")+1)
		
		if string.find(currentline,",") then --load type of object
			object_type[objectnum]=string.sub(currentline,1,string.find(currentline,",")-1)
		else
			object_type[objectnum]=currentline
		end
		
		if object_type[objectnum]=="platform" then --load shape coordinates/width/height for platforms
			local shapenum=1
			while string.find(currentline,",") do
				shape_x[objectnum]={}
				shape_y[objectnum]={}
				shape_width[objectnum]={}
				shape_height[objectnum]={}
			
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				shape_x[objectnum][shapenum]=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				shape_y[objectnum][shapenum]=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				shape_width[objectnum][shapenum]=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				
				if not string.find(currentline,",")==0 then
					shape_height[objectnum][shapenum]=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				else
					shape_height[objectnum][shapenum]=currentline
				end
				
				shapenum=shapenum+1
			end
			shape_amount[objectnum]=shapenum-1
		end
		objectnum=objectnum+1
	end
	file:close()
end

function createlevel()
	world=love.physics.newWorld(love.graphics.getWidth(),love.graphics.getHeight())
	world:setGravity(0,500)
	
	anchor={} --static bodies
	platform={} --dynamic bodies
	platform_shape={} --obvious
	joint={} --revolute joints connecting anchors and platforms
	
	local a, b
	for a=1,objectnum-1 do
		if object_type[a]=="platform" then --create platforms
			anchor[a]=love.physics.newBody(world,object_x[a],object_y[a])
			platform[a]=love.physics.newBody(world,object_x[a],object_y[a])
			for b=1,shape_amount[a] do
				platform_shape[a]={}
				platform_shape[a][b]=love.physics.newRectangleShape(platform[a],shape_x[a][b],shape_y[a][b],shape_width[a][b],shape_height[a][b])
			end
			platform[a]:setBullet(true)
			joint[a]=love.physics.newRevoluteJoint(anchor[a],platform[a],object_x[a],object_y[a])
		end
		
		if object_type[a]=="ball" then --create ball
			ball=love.physics.newBody(world,object_x[a],object_y[a])
			ball_shape=love.physics.newCircleShape(ball,0,0,16)
			ball:setMassFromShapes()
		end
	end
end
